import { renderless, api } from '@opentinyvue/vue-renderless/signature/vue';
import { defineComponent, props, Teleport, setup } from '@opentinyvue/vue-common';
import { IconFullscreen, IconMinscreenRight } from '@opentinyvue/vue-icon';
import Button from '@opentinyvue/vue-button';
import Modal from '@opentinyvue/vue-modal';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  emits: ["submit", "rewrite", "start", "end", "signing", "cancel"],
  props: [].concat(props, ["type", "height", "penColor", "lineWidth", "rewriteButtonText", "resignButtonText", "cancelButtonText", "backgroundColor", "submitButtonText", "placeholder", "showSubmitButton", "value"]),
  components: {
    TinyButton: Button,
    Teleport,
    IconFullscreen: IconFullscreen(),
    IconMinscreenRight: IconMinscreenRight()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      extendOptions: {
        Modal
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("teleport", {
    staticClass: "w-full h-full",
    attrs: {
      "to": "body",
      "data-tag": "tiny-signature",
      "disabled": !_vm.state.isFullscreen
    }
  }, [_c("div", {
    ref: "wrapRef",
    class: ["flex justify-center items-center bg-color-bg-2", _vm.state.isFullscreen ? "fixed inset-0 z-[9999]" : "relative", _vm.state.current === "default" && _vm.state.isFullscreen ? "rotate-90 w-[100vh] h-[100vw]" : "w-full h-full"],
    staticStyle: {
      "transform-origin": "calc(100vw / 2) center"
    }
  }, [_c("div", {
    staticClass: "absolute cursor-pointer p-2 right-1 top-1",
    on: {
      "click": _vm.toggleFullscreen
    }
  }, [_vm.state.isFullscreen ? _c("icon-minscreen-right", {
    staticClass: "w-6 h-6"
  }) : _c("icon-fullscreen", {
    staticClass: "w-6 h-6"
  })], 1), _vm.state.value ? _c("div", {
    staticClass: "absolute w-full h-full flex align-middle justify-center z-[999] bg-color-bg-2"
  }, [_c("img", {
    staticClass: "block max-w-full h-auto select-none",
    attrs: {
      "draggable": "false",
      "src": _vm.value
    }
  }), _c("tiny-button", {
    attrs: {
      "size": "small",
      "type": "text",
      "custom-class": "absolute right-2 bottom-2 text-color-info-primary"
    },
    on: {
      "click": _vm.rewrite
    }
  }, [_vm._v(_vm._s(_vm.resignButtonText))])], 1) : _vm._e(), _c("div", {
    staticClass: "w-full h-full",
    attrs: {
      "data-tag": "tiny-signature__content"
    }
  }, [_c("canvas", {
    ref: "canvasRef",
    staticClass: "w-full h-full",
    attrs: {
      "width": _vm.state.width,
      "height": _vm.state.height,
      "data-tiny-touch-simulate-container": ""
    },
    on: {
      "&touchstart": function touchstart($event) {
        return _vm.touchStart.apply(null, arguments);
      },
      "touchmove": _vm.touchMove,
      "touchend": _vm.touchEnd
    }
  })]), _c("div", {
    staticClass: "absolute flex justify-end origin-top right-2 bottom-2",
    attrs: {
      "data-tag": "tiny-signature__footer"
    }
  }, [_c("tiny-button", {
    attrs: {
      "size": "small",
      "type": "text",
      "custom-class": "mt-2 -mr-1 text-color-info-primary"
    },
    on: {
      "click": _vm.rewrite
    }
  }, [_vm._v(_vm._s(_vm.rewriteButtonText))]), _vm.state.current !== "default" && _vm.state.isFullscreen ? _c("tiny-button", {
    attrs: {
      "size": "small",
      "custom-class": "mt-2"
    },
    on: {
      "click": _vm.cancel
    }
  }, [_vm._v(_vm._s(_vm.cancelButtonText))]) : _vm._e(), _vm.showSubmitButton ? _c("tiny-button", {
    attrs: {
      "size": "small",
      "type": "primary",
      "custom-class": "mt-2 ml-1"
    },
    on: {
      "click": _vm.submit
    }
  }, [_vm._v(_vm._s(_vm.submitButtonText))]) : _vm._e()], 1)])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
